==> haskell-arch-web-0.1.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-web
version:              0.1.0
visibility:           public
id:                   arch-web-0.1.0-Fo3PkrW3Pi6Bz4aehfrjHT
key:                  arch-web-0.1.0-Fo3PkrW3Pi6Bz4aehfrjHT
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  54383d9d897938767ca13192830315a5
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-8.10.4/site-local/arch-web-0.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/arch-web-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/arch-web-0.1.0
hs-libraries:         HSarch-web-0.1.0-Fo3PkrW3Pi6Bz4aehfrjHT
depends:
    aeson-1.5.6.0-GONgLS6yTtf17t9dlS8fIx base-4.14.1.0
    deriving-aeson-0.2.6.1-7Li5i3oYMSgCTDNKTdQ8d9 exceptions-0.10.4
    http-client-0.7.6-G9lB0SI44qcITuwr9igRR3
    http-client-tls-0.3.5.3-49EYFNJPO5K72zSd6dLQMG
    http-types-0.12.3-EhuIez3q1reELpcE0UXNI1
    lens-5-F4KEgIRUc5WJcWGryULIOm mtl-2.2.2
    servant-0.18.2-6mdas0swsxv73MKEDcvOdz
    servant-client-0.18.2-6s7SuVX7rjuIgexU9SKaNF
    servant-client-core-0.18.2-JxiAsApfWuO2fIl60AUKud text-1.2.4.1
    time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arch-web-0.1.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arch-web
version:              0.1.0
visibility:           public
id:                   arch-web-0.1.0-COU3lCOoOvcAqWWMdXsR2P
key:                  arch-web-0.1.0-COU3lCOoOvcAqWWMdXsR2P
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  29fae6c4a42e7e4bbe8ff8f40fb7efe6
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-8.10.4/site-local/arch-web-0.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/arch-web-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/arch-web-0.1.0
hs-libraries:         HSarch-web-0.1.0-COU3lCOoOvcAqWWMdXsR2P
depends:
    aeson-1.5.6.0-I7BbKEwOl3UEL7J6p5LGbn base-4.14.1.0
    deriving-aeson-0.2.6.1-JPEubC9HAwDBq6GNgIgJ9M exceptions-0.10.4
    http-client-0.7.6-8pMd78HBmoq5UuVTsAFs62
    http-client-tls-0.3.5.3-5u2GgnIoy8I7prl9s6WhGv
    http-types-0.12.3-K6U5ABdDf9a5rAhqpLKr8V
    lens-5-IisTfvhUixNJI7BAb2F1um mtl-2.2.2
    servant-0.18.2-Gmx2ytb34m9KpyhdMBw5Ru
    servant-client-0.18.2-FxteeFMCUAH5ypNnExk0fx
    servant-client-core-0.18.2-JKwtkwAFgtv2skXXW9bZs5 text-1.2.4.1
    time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
